@@ -3,33 +3,6 @@ from pyspark.mllib.regression import LabeledPoint
 import numpy as np
 
 from ..mllib.adapter import to_vector, from_vector
-try:
-    from elephas.java import java_classes
-    from elephas.java.ndarray import ndarray
-except Exception:
-    print("WARNING")
-
-
-def to_java_rdd(jsc, features, labels, batch_size):
-    """Convert numpy features and labels into a JavaRDD of
-    DL4J DataSet type.
-
-    :param jsc: JavaSparkContext from pyjnius
-    :param features: numpy array with features
-    :param labels: numpy array with labels:
-    :return: JavaRDD<DataSet>
-    """
-    data_sets = java_classes.ArrayList()
-    num_batches = int(len(features) / batch_size)
-    for i in range(num_batches):
-        xi = ndarray(features[:batch_size].copy())
-        yi = ndarray(labels[:batch_size].copy())
-        data_set = java_classes.DataSet(xi.array, yi.array)
-        data_sets.add(data_set)
-        features = features[batch_size:]
-        labels = labels[batch_size:]
-
-    return jsc.parallelize(data_sets)
 
 
 def to_simple_rdd(sc: SparkContext, features: np.array, labels: np.array):
